#include "mesh_handler.h"

const struct bt_mesh_comp* (*init_ptr)(void);

void init_mesh(const struct bt_mesh_comp* (*ptr)(void)){
    init_ptr = ptr;
	printk("Initializing...\n");
	int err = bt_enable(bt_ready);
	if (err) {
		printk("Bluetooth init failed (err %d)\n", err);
	}
}

void bt_ready(int err){

  	char addr_s[BT_ADDR_LE_STR_LEN];
	bt_addr_le_t addr = {0};
	size_t count = 1;
	if (err) {
		printk("Bluetooth init failed (err %d)\n", err);
		return;
	}

	printk("Bluetooth initialized\n");

	dk_leds_init();
	dk_buttons_init(NULL);

    if(!init_ptr){
        printk("ERROR: no node init function given (call init_mesh first)");
        return;
    }
        
	err = bt_mesh_init(bt_mesh_dk_prov_init(), init_ptr());
	if (err) {
		printk("Initializing mesh failed (err %d)\n", err);
		return;
	}

	if (IS_ENABLED(CONFIG_SETTINGS)) {
		settings_load();
	}

	/* This will be a no-op if settings_load() loaded provisioning info */
	bt_mesh_prov_enable(BT_MESH_PROV_ADV | BT_MESH_PROV_GATT);

	printk("Mesh initialized\n");

  	bt_id_get(&addr, &count);
	bt_addr_le_to_str(&addr, addr_s, sizeof(addr_s));

	char name[50] = CONFIG_BT_DEVICE_NAME;
	name [strlen(name)] = '-';
	char mac[6];
	strncpy(mac, addr_s, 5);
	mac[5] = '\0';

	strcat(name, mac);
	
	err = bt_set_name(name);
	if(err){
		printk("Error while setting name (err %d)\n", err);
		return;
	}
}